@@ -728,6 +728,8 @@ static void evt_cmd_complete(struct bthost *bthost, const void *data,
 		break;
 	case BT_HCI_CMD_LE_SET_ADV_ENABLE:
 		break;
+	case BT_HCI_CMD_LE_SET_ADV_PARAMETERS:
+		break;
 	case BT_HCI_CMD_PIN_CODE_REQUEST_REPLY:
 		break;
 	case BT_HCI_CMD_PIN_CODE_REQUEST_NEG_REPLY:
@@ -1059,7 +1061,8 @@ static void evt_le_ltk_request(struct bthost *bthost, const void *data,
 	const struct bt_hci_evt_le_long_term_key_request *ev = data;
 	struct bt_hci_cmd_le_ltk_req_reply cp;
 	struct bt_hci_cmd_le_ltk_req_neg_reply *neg_cp = (void *) &cp;
-	uint16_t handle, div;
+	uint16_t handle, ediv;
+	uint64_t rand;
 	struct btconn *conn;
 	int err;
 
@@ -1071,11 +1074,12 @@ static void evt_le_ltk_request(struct bthost *bthost, const void *data,
 	if (!conn)
 		return;
 
-	div = le16_to_cpu(ev->diversifier);
+	rand = le64_to_cpu(ev->rand);
+	ediv = le16_to_cpu(ev->ediv);
 
 	cp.handle = ev->handle;
 
-	err = smp_get_ltk(conn->smp_data, ev->number, div, cp.ltk);
+	err = smp_get_ltk(conn->smp_data, rand, ediv, cp.ltk);
 	if (err < 0)
 		send_command(bthost, BT_HCI_CMD_LE_LTK_REQ_NEG_REPLY,
 						neg_cp, sizeof(*neg_cp));
@@ -2069,6 +2073,12 @@ void bthost_write_scan_enable(struct bthost *bthost, uint8_t scan)
 
 void bthost_set_adv_enable(struct bthost *bthost, uint8_t enable)
 {
+	struct bt_hci_cmd_le_set_adv_parameters cp;
+
+	memset(&cp, 0, sizeof(cp));
+	send_command(bthost, BT_HCI_CMD_LE_SET_ADV_PARAMETERS,
+							&cp, sizeof(cp));
+
 	send_command(bthost, BT_HCI_CMD_LE_SET_ADV_ENABLE, &enable, 1);
 }
 
