@@ -35,14 +35,92 @@
 #include <dbus/dbus.h>
 #include <gdbus/gdbus.h>
 
+#include "src/error.h"
+
 #define GATT_MGR_IFACE			"org.bluez.GattManager1"
 #define GATT_SERVICE_IFACE		"org.bluez.GattService1"
+#define GATT_CHR_IFACE			"org.bluez.GattCharacteristic1"
 
 /* Immediate Alert Service UUID */
 #define IAS_UUID			"00001802-0000-1000-8000-00805f9b34fb"
+#define ALERT_LEVEL_CHR_UUID		"00002a06-0000-1000-8000-00805f9b34fb"
 
 static GMainLoop *main_loop;
 static GSList *services;
+static DBusConnection *connection;
+
+struct characteristic {
+	char *uuid;
+	char *path;
+	uint8_t *value;
+	int vlen;
+};
+
+static gboolean chr_get_uuid(const GDBusPropertyTable *property,
+					DBusMessageIter *iter, void *user_data)
+{
+	struct characteristic *chr = user_data;
+
+	dbus_message_iter_append_basic(iter, DBUS_TYPE_STRING, &chr->uuid);
+
+	return TRUE;
+}
+
+static gboolean chr_get_value(const GDBusPropertyTable *property,
+					DBusMessageIter *iter, void *user_data)
+{
+	struct characteristic *chr = user_data;
+	DBusMessageIter array;
+
+	printf("Get(\"Value\")\n");
+
+	dbus_message_iter_open_container(iter, DBUS_TYPE_ARRAY,
+					DBUS_TYPE_BYTE_AS_STRING, &array);
+
+	dbus_message_iter_append_fixed_array(&array, DBUS_TYPE_BYTE,
+						&chr->value, chr->vlen);
+
+	dbus_message_iter_close_container(iter, &array);
+
+	return TRUE;
+}
+
+static void chr_set_value(const GDBusPropertyTable *property,
+				DBusMessageIter *iter,
+				GDBusPendingPropertySet id, void *user_data)
+{
+	struct characteristic *chr = user_data;
+	DBusMessageIter array;
+	uint8_t *value;
+	int len;
+
+	printf("Set('Value', ...)\n");
+
+	if (dbus_message_iter_get_arg_type(iter) != DBUS_TYPE_ARRAY) {
+		printf("Invalid value for Set('Value'...)\n");
+		g_dbus_pending_property_error(id,
+					ERROR_INTERFACE ".InvalidArguments",
+					"Invalid arguments in method call");
+		return;
+	}
+
+	dbus_message_iter_recurse(iter, &array);
+	dbus_message_iter_get_fixed_array(&array, &value, &len);
+
+	g_free(chr->value);
+	chr->value = g_memdup(value, len);
+	chr->vlen = len;
+
+	g_dbus_pending_property_success(id);
+	g_dbus_emit_property_changed(connection, chr->path,
+						GATT_CHR_IFACE, "Value");
+}
+
+static const GDBusPropertyTable chr_properties[] = {
+	{ "UUID",	"s",	chr_get_uuid },
+	{ "Value", "ay", chr_get_value, chr_set_value, NULL },
+	{ }
+};
 
 static gboolean service_get_uuid(const GDBusPropertyTable *property,
 					DBusMessageIter *iter, void *user_data)
@@ -83,15 +161,53 @@ static const GDBusPropertyTable service_properties[] = {
 	{ }
 };
 
-static char *register_service(DBusConnection *conn, const char *uuid)
+static void chr_iface_destroy(gpointer user_data)
+{
+	struct characteristic *chr = user_data;
+
+	g_free(chr->uuid);
+	g_free(chr->value);
+	g_free(chr->path);
+	g_free(chr);
+}
+
+static gboolean register_characteristic(DBusConnection *conn, const char *uuid,
+						const uint8_t *value, int vlen,
+						const char *service_path)
+{
+	struct characteristic *chr;
+	static int id = 1;
+	char *path;
+	gboolean ret = TRUE;
+
+	path = g_strdup_printf("%s/characteristic%d", service_path, id++);
+
+	chr = g_new0(struct characteristic, 1);
+
+	chr->uuid = g_strdup(uuid);
+	chr->value = g_memdup(value, vlen);
+	chr->vlen = vlen;
+	chr->path = path;
+
+	if (!g_dbus_register_interface(conn, path, GATT_CHR_IFACE,
+					NULL, NULL, chr_properties,
+					chr, chr_iface_destroy)) {
+		printf("Couldn't register characteristic interface\n");
+		ret = FALSE;
+	}
+
+	return ret;
+}
+
+static char *register_service(const char *uuid)
 {
 	static int id = 1;
 	char *path;
 
 	path = g_strdup_printf("/service%d", id++);
-	if (g_dbus_register_interface(conn, path, GATT_SERVICE_IFACE,
+	if (!g_dbus_register_interface(connection, path, GATT_SERVICE_IFACE,
 				NULL, NULL, service_properties,
-				g_strdup(uuid), g_free) == FALSE) {
+				g_strdup(uuid), g_free)) {
 		printf("Couldn't register service interface\n");
 		g_free(path);
 		return NULL;
@@ -100,14 +216,29 @@ static char *register_service(DBusConnection *conn, const char *uuid)
 	return path;
 }
 
-static void create_services(DBusConnection *conn)
+static void create_services()
 {
 	char *service_path;
+	uint8_t level = 0;
 
-	service_path = register_service(conn, IAS_UUID);
+	service_path = register_service(IAS_UUID);
+	if (!service_path)
+		return;
+
+	/* Add Alert Level Characteristic to Immediate Alert Service
+	 * According to the IAS SPEC, reading <<Alert level>> is not allowed.
+	 * "Value" is readable for testing purpose only.
+	 */
+	if (!register_characteristic(connection, ALERT_LEVEL_CHR_UUID, &level,
+						sizeof(level), service_path)) {
+		printf("Couldn't register Alert Level characteristic (IAS)\n");
+		g_dbus_unregister_interface(connection, service_path,
+							GATT_SERVICE_IFACE);
+		g_free(service_path);
+		return;
+	}
 
 	services = g_slist_prepend(services, service_path);
-
 	printf("Registered service: %s\n", service_path);
 }
 
@@ -139,7 +270,7 @@ static void register_external_service(gpointer a, gpointer b)
 
 	msg = dbus_message_new_method_call("org.bluez", "/org/bluez",
 					GATT_MGR_IFACE, "RegisterService");
-	if (msg == NULL) {
+	if (!msg) {
 		printf("Couldn't allocate D-Bus message\n");
 		return;
 	}
@@ -154,7 +285,7 @@ static void register_external_service(gpointer a, gpointer b)
 
 	dbus_message_iter_close_container(&iter, &dict);
 
-	if (g_dbus_send_message_with_reply(conn, msg, &call, -1) == FALSE) {
+	if (!g_dbus_send_message_with_reply(conn, msg, &call, -1)) {
 		dbus_message_unref(msg);
 		return;
 	}
@@ -242,25 +373,24 @@ static guint setup_signalfd(void)
 int main(int argc, char *argv[])
 {
 	GDBusClient *client;
-	DBusConnection *dbus_conn;
 	guint signal;
 
 	signal = setup_signalfd();
 	if (signal == 0)
 		return -errno;
 
-	dbus_conn = g_dbus_setup_bus(DBUS_BUS_SYSTEM, NULL, NULL);
+	connection = g_dbus_setup_bus(DBUS_BUS_SYSTEM, NULL, NULL);
 
 	main_loop = g_main_loop_new(NULL, FALSE);
 
-	g_dbus_attach_object_manager(dbus_conn);
+	g_dbus_attach_object_manager(connection);
 
 	printf("gatt-service unique name: %s\n",
-				dbus_bus_get_unique_name(dbus_conn));
+				dbus_bus_get_unique_name(connection));
 
-	create_services(dbus_conn);
+	create_services();
 
-	client = g_dbus_client_new(dbus_conn, "org.bluez", "/org/bluez");
+	client = g_dbus_client_new(connection, "org.bluez", "/org/bluez");
 
 	g_dbus_client_set_connect_watch(client, connect_handler, NULL);
 
@@ -271,7 +401,7 @@ int main(int argc, char *argv[])
 	g_source_remove(signal);
 
 	g_slist_free_full(services, g_free);
-	dbus_connection_unref(dbus_conn);
+	dbus_connection_unref(connection);
 
 	return 0;
 }
